Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorFrancois Chouinard2012-06-12 12:43:40 +0000
committerFrancois Chouinard2012-06-12 12:43:40 +0000
commitc76e383b93007456b5f9f1fdc5fc9d6415cdaae2 (patch)
tree75b1a38213488596006f600d7ea27c8cb0a7a247 /lttng/org.eclipse.linuxtools.tmf.core.tests
parent9a6edbb3e54e4a76afbb02529ba9385cf5c93d75 (diff)
downloadorg.eclipse.linuxtools-c76e383b93007456b5f9f1fdc5fc9d6415cdaae2.tar.gz
org.eclipse.linuxtools-c76e383b93007456b5f9f1fdc5fc9d6415cdaae2.tar.xz
org.eclipse.linuxtools-c76e383b93007456b5f9f1fdc5fc9d6415cdaae2.zip
Revert "Fix for bug 381411: Incorrect experiment location after getNext."
Diffstat (limited to 'lttng/org.eclipse.linuxtools.tmf.core.tests')
-rw-r--r--lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfExperimentTest.java24
-rw-r--r--lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfMultiTraceExperimentTest.java24
-rw-r--r--lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfTraceTest.java27
3 files changed, 7 insertions, 68 deletions
diff --git a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfExperimentTest.java b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfExperimentTest.java
index b2b4a595ac..8a89d8e397 100644
--- a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfExperimentTest.java
+++ b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfExperimentTest.java
@@ -537,10 +537,10 @@ public class TmfExperimentTest extends TestCase {
}
// ------------------------------------------------------------------------
- // getNext - updates the context
+ // readtNextEvent - updates the context
// ------------------------------------------------------------------------
- public void testGetNext() throws Exception {
+ public void testReadNextEvent() throws Exception {
// On lower bound, returns the first event (ts = 0)
final ITmfContext context = fExperiment.seekEvent(0);
@@ -553,26 +553,6 @@ public class TmfExperimentTest extends TestCase {
}
}
- public void testGetNextLocation() throws Exception {
-
- ITmfContext context1 = fExperiment.seekEvent(0);
- fExperiment.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfEvent event1 = fExperiment.getNext(context1);
- ITmfContext context2 = fExperiment.seekEvent(location);
- ITmfEvent event2 = fExperiment.getNext(context2);
- assertEquals("Event timestamp", event1.getTimestamp().getValue(), event2.getTimestamp().getValue());
- }
-
- public void testGetNextEndLocation() throws Exception {
- ITmfContext context1 = fExperiment.seekEvent(fExperiment.getNbEvents() - 1);
- fExperiment.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfContext context2 = fExperiment.seekEvent(location);
- ITmfEvent event = fExperiment.getNext(context2);
- assertNull("Event", event);
- }
-
// ------------------------------------------------------------------------
// processRequest
// ------------------------------------------------------------------------
diff --git a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfMultiTraceExperimentTest.java b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfMultiTraceExperimentTest.java
index 740de4ceb6..b5d7198464 100644
--- a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfMultiTraceExperimentTest.java
+++ b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfMultiTraceExperimentTest.java
@@ -386,10 +386,10 @@ public class TmfMultiTraceExperimentTest extends TestCase {
}
// ------------------------------------------------------------------------
- // getNext - updates the context
+ // readtNextEvent - updates the context
// ------------------------------------------------------------------------
- public void testGetNext() throws Exception {
+ public void testReadNextEvent() throws Exception {
// On lower bound, returns the first event (ts = 0)
final ITmfContext context = fExperiment.seekEvent(0);
@@ -402,26 +402,6 @@ public class TmfMultiTraceExperimentTest extends TestCase {
}
}
- public void testGetNextLocation() throws Exception {
-
- ITmfContext context1 = fExperiment.seekEvent(0);
- fExperiment.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfEvent event1 = fExperiment.getNext(context1);
- ITmfContext context2 = fExperiment.seekEvent(location);
- ITmfEvent event2 = fExperiment.getNext(context2);
- assertEquals("Event timestamp", event1.getTimestamp().getValue(), event2.getTimestamp().getValue());
- }
-
- public void testGetNextEndLocation() throws Exception {
- ITmfContext context1 = fExperiment.seekEvent(fExperiment.getNbEvents() - 1);
- fExperiment.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfContext context2 = fExperiment.seekEvent(location);
- ITmfEvent event = fExperiment.getNext(context2);
- assertNull("Event", event);
- }
-
// ------------------------------------------------------------------------
// processRequest
// ------------------------------------------------------------------------
diff --git a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfTraceTest.java b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfTraceTest.java
index aacc1aef90..bb73b1bcab 100644
--- a/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfTraceTest.java
+++ b/lttng/org.eclipse.linuxtools.tmf.core.tests/src/org/eclipse/linuxtools/tmf/core/tests/trace/TmfTraceTest.java
@@ -35,7 +35,6 @@ import org.eclipse.linuxtools.tmf.core.request.TmfDataRequest;
import org.eclipse.linuxtools.tmf.core.request.TmfEventRequest;
import org.eclipse.linuxtools.tmf.core.tests.TmfCoreTestPlugin;
import org.eclipse.linuxtools.tmf.core.trace.ITmfContext;
-import org.eclipse.linuxtools.tmf.core.trace.ITmfLocation;
import org.eclipse.linuxtools.tmf.core.trace.ITmfTrace;
import org.eclipse.linuxtools.tmf.core.trace.TmfCheckpointIndexer;
import org.eclipse.linuxtools.tmf.core.trace.TmfContext;
@@ -969,10 +968,10 @@ public class TmfTraceTest extends TestCase {
}
// ------------------------------------------------------------------------
// getNext - updates the context
// ------------------------------------------------------------------------
- public void testGetNext() throws Exception {
+ public void testReadNextEvent() throws Exception {
final int NB_READS = 20;
@@ -993,26 +992,6 @@ public class TmfTraceTest extends TestCase {
assertEquals("Event rank", NB_READS, context.getRank());
}
- public void testGetNextLocation() throws Exception {
-
- ITmfContext context1 = fTrace.seekEvent(0);
- fTrace.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfEvent event1 = fTrace.getNext(context1);
- ITmfContext context2 = fTrace.seekEvent(location);
- ITmfEvent event2 = fTrace.getNext(context2);
- assertEquals("Event timestamp", event1.getTimestamp().getValue(), event2.getTimestamp().getValue());
- }
-
- public void testGetNextEndLocation() throws Exception {
- ITmfContext context1 = fTrace.seekEvent(fTrace.getNbEvents() - 1);
- fTrace.getNext(context1);
- ITmfLocation<?> location = context1.getLocation().clone();
- ITmfContext context2 = fTrace.seekEvent(location);
- ITmfEvent event = fTrace.getNext(context2);
- assertNull("Event", event);
- }
-
// ------------------------------------------------------------------------
// processRequest
// ------------------------------------------------------------------------
@@ -1217,4 +1196,4 @@ public class TmfTraceTest extends TestCase {
assertEquals("toString", expected, fTrace.toString());
}
-}
+} \ No newline at end of file

Back to the top
@@ -969,10 +968,10 @@ public class TmfTraceTest extends TestCase {
}
// ------------------------------------------------------------------------
- // getNext - updates the context
+ // readNextEvent - updates the context
// ------------------------------------------------------------------------